import requests
import xbmc
import xbmcgui
from datetime import datetime

API_URL = "https://monflix.atwebpages.com/api_login.php"
API_LOGOUT_URL = "https://monflix.atwebpages.com/api_logout.php"

def check_credentials(username, password):
    try:
        # Modificato per inviare i dati come form-urlencoded
        response = requests.post(API_URL, data={'username': username, 'password': password})
        
        if response.status_code == 200:
            data = response.json()
            
            # Controlla se la data di scadenza è presente
            data_scadenza = data.get('data_scadenza')
            if data_scadenza is None:
                xbmcgui.Dialog().notification('Errore', 'Data di scadenza non trovata', xbmcgui.NOTIFICATION_ERROR, 3000)
                return False

            try:
                # Assicurati che la data di scadenza sia nel formato corretto
                data_scadenza = datetime.strptime(data_scadenza, "%Y-%m-%d %H:%M:%S")
            except ValueError:
                xbmcgui.Dialog().notification('Errore', 'Formato della data di scadenza non valido', xbmcgui.NOTIFICATION_ERROR, 3000)
                return False
            
            # Verifica se l'account è scaduto
            if datetime.now() > data_scadenza:
                xbmcgui.Dialog().notification('Login', 'L\'account è scaduto', xbmcgui.NOTIFICATION_ERROR, 3000)
                return False
            
            # Controllo del limite di sessioni attive
            active_sessions = data.get('active_sessions', 0)
            if active_sessions < 2:
                xbmcgui.Dialog().notification('Login', 'Login effettuato con successo', xbmcgui.NOTIFICATION_INFO, 3000)
                return True
            else:
                xbmcgui.Dialog().notification('Login', 'Limite di accessi contemporanei superato', xbmcgui.NOTIFICATION_ERROR, 3000)
                return False
        else:
            xbmcgui.Dialog().notification('Login', 'Credenziali non valide', xbmcgui.NOTIFICATION_ERROR, 3000)
            return False
    except requests.exceptions.RequestException as e:
        xbmcgui.Dialog().notification('Errore', f"Errore durante il login: {str(e)}", xbmcgui.NOTIFICATION_ERROR, 5000)
        return False

def logout(username):
    try:
        # Richiesta per il logout
        response = requests.post(API_LOGOUT_URL, data={'username': username})
        
        if response.status_code == 200:
            xbmcgui.Dialog().notification('Logout', f"{username} ha effettuato il logout.", xbmcgui.NOTIFICATION_INFO, 3000)
            return True
        else:
            xbmcgui.Dialog().notification('Errore', 'Errore durante il logout', xbmcgui.NOTIFICATION_ERROR, 3000)
            return False
    except requests.exceptions.RequestException as e:
        xbmcgui.Dialog().notification('Errore', f"Errore durante il logout: {str(e)}", xbmcgui.NOTIFICATION_ERROR, 5000)
        return False